<?php

//Content width
if ( ! isset( $content_width ) ) $content_width = 940;
//Content width

//Clean the head
add_action( 'wp_enqueue_scripts', 'ac_remove_cf7_scripts' );
function ac_remove_cf7_scripts() {
	wp_deregister_style( 'contact-form-7' );
	wp_deregister_script('l10n');
}

function remove_recent_comments_style() {
    global $wp_widget_factory;
    remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
}
add_action('widgets_init', 'remove_recent_comments_style');
//Clean the head

//Content width
if ( ! isset( $content_width ) ) $content_width = 1100;
//Content width

//After theme setup
add_action( 'after_setup_theme', 'post_thumbnail_support' );
function post_thumbnail_support() {
	//Thumbnails
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'post-thumbnail-big', 568, 300,true );
	
	//Post formats
	add_theme_support( 'post-formats', array( 'gallery', 'video', 'link', 'audio', 'quote', 'aside' ) );
	 add_theme_support( 'structured-post-formats', array(
	 	'image', 'gallery', 'link', 'video', 'audio', 'chat', 'status', 'quote', 'aside'
	 ) );
	
	//Editor style
	add_editor_style('editor-style.css');
	
	//RSS link
	add_theme_support( 'automatic-feed-links' );
	
	//Languages
	load_theme_textdomain( 'wedding', get_template_directory() . '/languages' );
}
//After theme setup

//Wordpress Title
function site_title() {
	global $page, $paged;
	wp_title( '|', true, 'right' );
	bloginfo( 'name' );
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'wedding' ), max( $paged, $page ) );
}
//Wordpress Title

//Include Frontend Javascript and CSS
function wedding_scripts() {

	//Main CSS file
	wp_enqueue_style( 'wedding-style', get_bloginfo( 'stylesheet_url' ) );

	//Modernizer
	wp_register_script( 'modernizr-js', get_template_directory_uri() . '/js/html5.js', array( 'jquery') );
	wp_enqueue_script('modernizr-js');

	//Fancybox
	wp_register_script( 'fancybox-js', get_template_directory_uri() . '/js/fancybox/jquery.fancybox-1.3.4.pack.js', array( 'jquery') );
	wp_register_style('fancybox-css', get_template_directory_uri().'/js/fancybox/jquery.fancybox-1.3.4.css');
	wp_enqueue_script('fancybox-js');
	wp_enqueue_style('fancybox-css');

	//MediaElement.JS
	wp_register_script( 'mediaelement-js', get_template_directory_uri() . '/js/mediaelement/mediaelement-and-player.min.js', array( 'jquery') );
	wp_register_style( 'mediaelement-css', get_template_directory_uri() . '/js/mediaelement/mediaelementplayer.min.css' );

	//bxSlider
	wp_register_script( 'slider-js', get_template_directory_uri() . '/js/slider/layerslider.js', array( 'jquery') );
	wp_register_style( 'slider-css', get_template_directory_uri() . '/js/slider/layerslider.css' );
	wp_enqueue_script('slider-js');
	wp_enqueue_style('slider-css');
	wp_localize_script('slider-js', 'slider_skin', array(
		'path' => get_template_directory_uri().'/js/slider/'
	));
	
	//jQuery One Page Nav JS
	wp_register_script( 'jquery-nav-js', get_template_directory_uri() . '/js/jquery.nav.js', array( 'jquery') );
	wp_enqueue_script('jquery-nav-js');
	
	//ELASTISLIDE
	wp_register_script( 'jquery-elastislide-js', get_template_directory_uri() . '/js/jquery.elastislide.js', array( 'jquery') );
	
	//Global JS
	wp_register_script( 'wedding-js', get_template_directory_uri() . '/js/global.js', array( 'jquery') );
	wp_enqueue_script('wedding-js');
	
}
add_action('wp_enqueue_scripts', 'wedding_scripts');
//Include Frontend Javascript and CSS

//Include Generated CSS and Custom CSS & JS codes
function wedding_dynamic_css() {
	
	$body_font = wedding_field('body_font');
	$header_font = wedding_field('header_font');
	$section_font = wedding_field('section_font');
	$menu_font = wedding_field('menu_font');
	$logo_center = wedding_field('logo_center');
	
	//Load default fonts
	if (!$body_font) wp_enqueue_style( "wedding_body_font_ubuntu", "http://fonts.googleapis.com/css?family=Ubuntu:400,700,400italic" ); 
	if (!$header_font) wp_enqueue_style( "wedding_header_font_bebas_neue", get_template_directory_uri() . '/css/bebas-neue.css');
	if (!$section_font) wp_enqueue_style( "wedding_section_font_silverfake", get_template_directory_uri() . '/css/silverfake.css');
	if (!$menu_font) wp_enqueue_style( "wedding_menu_font_balthazar", "http://fonts.googleapis.com/css?family=Balthazar");

	//Load extra fonts if needed
	if (array_key_exists($body_font, options_typography_get_google_fonts())) {
		$font = explode(',', $body_font);
		$font = $font[0];
		$font = str_replace(" ", "+", $font);
		wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800", false, null, 'all' );
	}
	
	if (array_key_exists($header_font, options_typography_get_google_fonts())) {
		$font = explode(',', $header_font);
		$font = $font[0];
		$font = str_replace(" ", "+", $font);
		wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font:400,700", false, null, 'all' );
	}
	
	if (array_key_exists($section_font, options_typography_get_google_fonts())) {
		$font = explode(',', $section_font);
		$font = $font[0];
		$font = str_replace(" ", "+", $font);
		wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font:400,700", false, null, 'all' );
	}
	
	if (array_key_exists($menu_font, options_typography_get_google_fonts())) {
		$font = explode(',', $menu_font);
		$font = $font[0];
		$font = str_replace(" ", "+", $font);
		wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font:400,700", false, null, 'all' );
	}	

	function hex2rgb($hex) {
	   $hex = str_replace("#", "", $hex);
	
	   if(strlen($hex) == 3) {
	      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
	      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
	      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
	   } else {
	      $r = hexdec(substr($hex,0,2));
	      $g = hexdec(substr($hex,2,2));
	      $b = hexdec(substr($hex,4,2));
	   }
	   $rgb = array($r, $g, $b);
	   return $rgb;
	}
    ?>
    <style type="text/css">
	    body {
	    	font-size:<?php echo wedding_field('font_size'); ?>;
	    	line-height: <?php echo wedding_field('line_height'); ?>;
	    	<?php if($body_font): ?>
	    	font-family: <?php echo $body_font; ?>;
	    	<?php endif; ?>
	    }
	    
		<?php if($header_font): ?>
		h1,h2,h3,h4,h5,h6,.header-font,blockquote {font-family: <?php echo $header_font; ?>;}
		<?php endif; ?>
		
		<?php if($section_font): ?>
		.section-title h1, span.dropcap {font-family: <?php echo $section_font; ?>;}
		<?php endif; ?>
		
		<?php if($menu_font): ?>
		header.header nav.main a {font-family: <?php echo $menu_font; ?>;}
		<?php endif; ?>
		
		<?php
		$layout = wedding_field('layout');
		$primary_color = wedding_field('primary_color');
		$secondary_color = wedding_field('secondary_color');
		$text_color = wedding_field('text_color');
		$title_color = wedding_field('title_color');
		$box_color = wedding_field('box_color');
		$box_text_color = wedding_field('box_text_color');
		$section_title_color = wedding_field('section_title_color');
		$body_bg_color = wedding_field('body_bg_color');
		$page_bg_color = wedding_field('page_bg_color');
		
		//Generate slightly darker colors for the section title tail and shadow
		preg_match('/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $primary_color, $title_tail);
		preg_match('/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $primary_color, $title_shadow);
		$title_tail_color = "";
		for($i = 1; $i <= 3; $i++) {
			$title_tail[$i] = hexdec($title_tail[$i]);
			$title_tail[$i] = round($title_tail[$i] * 92/100);
			$title_tail_color .= str_pad(dechex($title_tail[$i]), 2, '0', STR_PAD_LEFT);
		}
		$title_shadow_color = "";
		for($i = 1; $i <= 3; $i++) {
			$title_shadow[$i] = hexdec($title_shadow[$i]);
			$title_shadow[$i] = round($title_shadow[$i] * 77/100);
			$title_shadow_color .= str_pad(dechex($title_shadow[$i]), 2, '0', STR_PAD_LEFT);
		}
		?>
		
		/* Primary Color */
		.primary-color,
		a,
		.menu li[class^="icon-"] a:hover,
		.menu li[class^="icon-"]:hover:before,
		header.header nav.main a:hover,
		header.header nav.main li.current-menu-item > a,
		header.header nav.main li.current-menu-ancestor > a,
		header.header nav.main li.current_page_item > a,
		header.header nav.main li.current_page_ancestor > a,
		header.header nav.main li.current_page_parent > a,
		header.header nav.main li.current_page_parent > a,
		header.header nav.main li.current > a,
		.box.box-icon:before,
		.gallery .gallery-item a:hover strong,
		ol.commentlist li.comment article header a.comment-reply-link:hover,
		.timeline a.link:hover,
		.timeline a.link:hover:before,
		.post_list article .entry-title h1 a:hover {color:<?php echo $primary_color; ?>}
		
		.primary-color-bg,
		.button,input[type=submit],
		.section-title h1,
		.tagcloud a,
		.social_icon:hover,
		.timeline .line,
		.timeline span.year {background-color: <?php echo $primary_color; ?>}
		
		.primary-color-border,
		.menu li[class^="icon-"] a:hover,
		.timeline .post .data .date:after {border-color: <?php echo $primary_color; ?>}
		
		.section-title h1:before, .section-title h1:after {border-color: #<?php echo $title_tail_color; ?>;}
		.section-title h1 span:before, .section-title h1 span:after {border-color: transparent transparent #<?php echo $title_shadow_color; ?> transparent;}
		/* Primary Color */
		
		/* Text Color */
		body,
		.gallery-summary em {color:<?php echo $text_color; ?>}
		/* Text Color */
		
		/* Title Color */
		h1,h2,h3,h4,h5,h6,
		header.header nav.main a,
		.box.recent_posts li a strong,
		.gallery .gallery-item a strong,
		.elastislide-wrapper nav span:hover,
		.widget_recent_entries ul li a,
		.tabs nav a,
		.toggle a.tab_title,
		ol.commentlist li.comment article header span.comment-author,
		#respond h3,
		blockquote {color:<?php echo $title_color; ?>}
		
		#wrapper ul.feature_list.big li h2:before,
		#wrapper ul.feature_list.small li h2:before {background-color: <?php echo $title_color; ?>}
		
		<?php if($section_title_color): ?>.section-title h1,.timeline span.year {color:<?php echo $section_title_color; ?>}<?php endif; ?>
		/* Title Color */
		
		/* Secondary Color */
		h3,
		.timeline a.link:before,
		blockquote,
		.elastislide-wrapper nav span,
		.post_list .entry-meta li,
		.gallery .gallery-item a em,
		footer .copy {color: <?php echo $secondary_color; ?>;}
		
		span.dropcap.v2,
		.social_icon,
		.timeline .post .data .date,
		.timeline .post .data .date:before,
		.ajax-load-posts a {background-color: <?php echo $secondary_color; ?>;}
		/* Secondary Color */
		
		/* Box Color */
		.box,
		#wrapper div.wpcf7,
		.widget_recent_entries ul,
		.tabs .panes,
		.toggle,
		ol.commentlist li.comment article,
		ol.commentlist li.comment article:before,
		#respond #commentform,
		.timeline .post .post_content .box:before,
		.post_list article .box.post-content:before,
		#searchform input {background-color: <?php echo $box_color; ?>}
		
		<?php if($box_text_color): ?>
			.box,
			.box blockquote {color: <?php echo $box_text_color; ?>;}
			
			.post_list article .entry-title time,
			.widget_recent_entries ul li span.post-date,
			#searchform input {color: rgba(<?php echo implode(',',hex2rgb($box_text_color)); ?>,0.5);}
			
			.box.recent_posts li a,
			.widget_recent_entries ul li {border-color:rgba(<?php echo implode(',',hex2rgb($box_text_color)); ?>,0.3);}
		<?php endif; ?>
		/* Box Color */
		
		/* Body BG Color */
		body {
			background: <?php echo $body_bg_color; ?> <?php if(wedding_field('body_bg_img')): ?>url(<?php echo wedding_field('body_bg_img');?>) <?php echo wedding_field('body_bg_props'); ?><?php endif; ?>;
			<?php if(wedding_field('body_bg_full')): ?>background-size:cover;<?php endif; ?>
		}
		
		<?php if ($layout == 'full-width'): ?>
			.timeline .post:last-child:before,
			.hr.top a,
			.timeline .post .data .date:after {background-color: <?php echo $body_bg_color; ?>;}
			
			.timeline span.year {border-color: <?php echo $body_bg_color; ?>;}
			
			.timeline .post .data .date:after {
				-moz-box-shadow: 0 0 0 5px <?php echo $body_bg_color; ?>;
				-webkit-box-shadow: 0 0 0 5px <?php echo $body_bg_color; ?>;
				box-shadow: 0 0 0 5px <?php echo $body_bg_color; ?>;
			}
		<?php else: ?>
			<?php if($page_bg_color): ?>
			.timeline .post:last-child:before,
			.hr.top a,
			.timeline .post .data .date:after {background-color: <?php echo $page_bg_color; ?>;}
			
			.timeline span.year {border-color: <?php echo $page_bg_color; ?>;}
			
			.timeline .post .data .date:after {
				-moz-box-shadow: 0 0 0 5px <?php echo $page_bg_color; ?>;
				-webkit-box-shadow: 0 0 0 5px <?php echo $page_bg_color; ?>;
				box-shadow: 0 0 0 5px <?php echo $page_bg_color; ?>;
			}
			
			body.boxed .page-container {
				background: <?php echo $page_bg_color; ?>;
			}
			<?php endif; ?>
		<?php endif; ?>
		
		/* Body BG Color */
		
		<?php if ($logo_center): ?>
		header.header .content {max-width:100%;text-align:center;}
		header.header #logo {float:none;margin:0 !important;}
		header.header #logo span.img {margin:0; padding:0;}
		header.header #logo span.subtitle {display:block;padding:10px 0 0 0;}
		header.header #logo span.subtitle:empty {display: none;}
		header.header #logo span.img:after {display:none;}
		header.header #logo img {max-width:100%;}
		<?php endif; ?>
		
		<?php echo wedding_field('custom_css'); ?>
    </style>
    <?php echo wedding_field('custom_js'); ?>
    <?php
    
    
}
add_action( 'wp_head', 'wedding_dynamic_css' );
//Include Generated CSS and Custom CSS & JS codes

//Check if the layout is Boxed or not
function wedding_body_layout($classes) {
	if (wedding_field('layout') == 'boxed') $classes[] = 'boxed';
    return $classes;
}
add_filter('body_class', 'wedding_body_layout');
//Check if the layout is Boxed or not

//Include Favicon
function wedding_favicon() {
	if (wedding_field('favicon')):
	echo '<link rel="shortcut icon" href="'.wedding_field('favicon').'" />';
	endif;
}
add_action('wp_head', 'wedding_favicon');
//Include Favicon

//Post meta
function wedding_post_meta() {
	?>
	<ul>
		<li class="by-author icon-user">
			<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>" title="<?php echo sprintf( __( 'View all posts by %s', 'wedding' ), get_the_author() ); ?>" rel="author">
				<?php echo get_the_author(); ?>
			</a>
		</li>
		<li class="cat-links icon-folder">
			<?php echo get_the_category_list( ', ' ); ?>
		</li>
		<li class="comments icon-comment">
			<?php comments_popup_link( '' . __( 'Leave a reply', 'wedding' ) . '</span>', __( '1 comment', 'wedding' ), __( '% comments', 'wedding' ) ); ?>
		</li>
		<?php if (has_tag()): ?>
		<li class="tags icon-tag">
			<?php echo get_the_tag_list( '', ', ' ); ?>
		</li>
		<?php endif; ?>
		<?php if ((current_user_can('editor'))||(current_user_can('administrator'))): ?>
		<li><?php edit_post_link( __( 'Edit', 'wedding' ) ); ?></li>
		<?php endif; ?>
	</ul>
	<?php
}
//Post meta

//Sidebar selector and child menu toggle for left and right sidebar page templates
add_action('admin_init', 'register_page_custom_sidebar_field');
add_action('save_post', 'save_page_custom_sidebar_meta',10,2);

function register_page_custom_sidebar_field() {
	add_meta_box('page_custom_sidebar_meta', 'Custom Sidebar', 'page_custom_sidebar_meta_callback', 'page', 'side', 'low');
}

function page_custom_sidebar_meta_callback() {
	global $post;
	$custom = get_post_custom($post->ID);


	$old_value_custom_sidebar = '';
	if (isset($custom['page_custom_sidebar'][0])) $old_value_custom_sidebar = $custom['page_custom_sidebar'][0];

	$old_value_child_pages = '';
	if (isset($custom['page_show_child_pages'][0])) $old_value_child_pages = $custom['page_show_child_pages'][0];
	
	$checked = '';
	if ($old_value_child_pages) {
		$checked = 'checked="checked"';
	}
	
	echo '<div id="show_child_pages"><p><strong>'.__('Show child pages','wedding').':</strong> <input type="checkbox" value="on" name="page_show_child_pages" '.$checked.' /></p><p>'.__('Show child pages automatically in the sidebar','wedding').'</p></div>';
	
	$custom_sidebars = $GLOBALS['wp_registered_sidebars'];

	wp_nonce_field( basename( __FILE__ ), 'page_custom_sidebar_nonce' );
	?>
	<div id="page_custom_sidebar">
		<p>
			<strong><?php _e('Sidebar','wedding'); ?>:</strong>
		</p>
		<p>
			<?php if ($custom_sidebars): ?>
				<select name="page_custom_sidebar">
				<option value="" <?php if ($old_value_custom_sidebar == ''):?>selected="selected"<?php endif; ?>><?php _e('Default','wedding'); ?></option>
				<option value="none" <?php if ($old_value_custom_sidebar == 'none'):?>selected="selected"<?php endif; ?>><?php _e('None','wedding'); ?></option>
				<?php foreach ( $custom_sidebars as $sidebar ): ?>
					<option value="<?php echo $sidebar['id']; ?>" <?php if ($old_value_custom_sidebar == $sidebar['id']):?>selected="selected"<?php endif; ?>><?php echo $sidebar['name']; ?></option>
				<?php endforeach; ?>
				</select>
			<?php endif; ?>
		</p>
		<p><?php _e('You can create custom sidebars in the Theme Options / Advanced menu','wedding'); ?></p>
	</div>
	<?php
}

function save_page_custom_sidebar_meta($post_id, $post) {
	global $post;

	if ( !isset( $_POST['page_custom_sidebar_nonce'] ) || !wp_verify_nonce( $_POST['page_custom_sidebar_nonce'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;
		
	$post_meta = array();
	if (isset($_POST['page_custom_sidebar'])) $post_meta['page_custom_sidebar'] = $_POST['page_custom_sidebar'];
	if (isset($_POST['page_show_child_pages'])) $post_meta['page_show_child_pages'] = $_POST['page_show_child_pages'];

	foreach ($post_meta as $key => $value) {
		$new_meta_value = ( isset( $value ) ? $value : '' );
		$meta_key = $key;
		$meta_value = get_post_meta( $post_id, $meta_key, true );
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta_key, $meta_value );
	}

}
//Sidebar selector and child menu toggle for left and right sidebar page templates

//Slider selector for homepage template
add_action('admin_init', 'register_homepage_slider_field');
add_action('save_post', 'save_homepage_slider_meta',10,2);

function register_homepage_slider_field() {
	add_meta_box('homepage_slider_meta', __('Slider','wedding'), 'homepage_slider_meta_callback', 'page', 'side', 'low');
}

function homepage_slider_meta_callback() {
	global $post;
	$custom = get_post_custom($post->ID);

	$old_value = '';
	if (isset($custom['homepage_slider'][0])) $old_value = $custom['homepage_slider'][0];
	$old_value_html = '';
	if (isset($custom['homepage_slider_html'][0])) $old_value_html = $custom['homepage_slider_html'][0];

	// Get sliders
	$args = array(
		'post_type' => 'wedding_slider',
		'posts_per_page' => -1
	);
	$sliders = get_posts($args);
	
	wp_nonce_field( basename( __FILE__ ), 'homepage_slider_nonce' );
	
	?>
	<p><strong><?php _e('Select a slider','wedding') ?>:</strong></p>
	<p>
		<select name="homepage_slider">
			<option value=""><?php _e('None','wedding'); ?></option>
			<?php foreach($sliders as $slider): ?>
				<?php print_r($slider); ?>
				<option value="<?php echo $slider->ID; ?>"<?php if($old_value == $slider->ID):?> selected="selected"<?php endif; ?>><?php echo $slider->post_title; ?></option>
			<?php endforeach; ?>
		</select>
	</p>
	<p><strong><?php _e('Or use custom html/shortcode','wedding') ?>:</strong></p>
	<p><textarea name="homepage_slider_html" rows="5" style="width:100%"><?php echo $old_value_html; ?></textarea></p>
	<?php
}

function save_homepage_slider_meta($post_id, $post) {
	global $post;

	if ( !isset( $_POST['homepage_slider_nonce'] ) || !wp_verify_nonce( $_POST['homepage_slider_nonce'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	$post_meta = array();
	if (isset($_POST['homepage_slider'])) $post_meta['homepage_slider'] = $_POST['homepage_slider'];
	if (isset($_POST['homepage_slider_html'])) $post_meta['homepage_slider_html'] = $_POST['homepage_slider_html'];

	foreach ($post_meta as $key => $value) {
		$new_meta_value = ( isset( $value ) ? $value : '' );
		$meta_key = $key;
		$meta_value = get_post_meta( $post_id, $meta_key, true );
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta_key, $meta_value );
	}

}
//Slider selector for homepage template

//Post Format Additional Options
add_action('admin_init', 'register_post_format_additionals');
add_action('save_post', 'save_post_format_additionals',10, 2);

function register_post_format_additionals() {
	
	//Hide this metabox if we're using 3.6 or older
	if (version_compare(get_bloginfo('version'),"3.6",">=")) {
		add_filter( 'hidden_meta_boxes', 'custom_hidden_meta_boxes' );
		function custom_hidden_meta_boxes( $hidden ) {
		    $hidden[] = 'post_format_additionals_old';
		    return $hidden;
		}
		$post_format_metabox_id = 'post_format_additionals_old';
	} else {
		$post_format_metabox_id = 'post_format_additionals';
	}

	add_meta_box($post_format_metabox_id, __('Post Format Additional Options','wedding'), 'post_format_additionals_callback', 'post', 'side', 'low');
}

function post_format_additionals_callback() {
	global $post;
	$custom = get_post_custom($post->ID);
	
	$post_format_video_field = '';
	if (isset($custom['post_format_video_field'][0])) $post_format_video_field = $custom['post_format_video_field'][0];
	$post_format_audio_field = '';
	if (isset($custom['post_format_audio_field'][0])) $post_format_audio_field = $custom['post_format_audio_field'][0];
	$post_format_link_field = '';
	if (isset($custom['post_format_link_field'][0])) $post_format_link_field = $custom['post_format_link_field'][0];
	$post_format_quote_text_field = '';
	if (isset($custom['post_format_quote_text_field'][0])) $post_format_quote_text_field = $custom['post_format_quote_text_field'][0];
	$post_format_quote_from_field = '';
	if (isset($custom['post_format_quote_from_field'][0])) $post_format_quote_from_field = $custom['post_format_quote_from_field'][0];
	
	wp_nonce_field( basename( __FILE__ ), 'post_format_additionals' );
	
	?>
	<p id="post-type-default">
		<strong class="title"><?php _e('Default','wedding'); ?></strong>
		<small class="howto"><?php _e('This is the default format for all the posts. Title + description or Featured image + title + description.','wedding'); ?></small>
	</p>
	<p id="post-type-gallery">
		<strong class="title"><?php _e('Gallery','wedding'); ?></strong>
		<small class="howto"><?php _e('Slideshow created with the attachment images. You just need to add some image attachments to the post by clicking Add Media button.','wedding'); ?></small>
	</p>
	<p id="post-type-video">
		<strong><?php _e('Video Link','wedding'); ?></strong>
		<textarea name="post_format_video_field" placeholder="http://www.youtube.com/watch?v=Jcu1AHaTchM"><?php echo $post_format_video_field; ?></textarea><br/>
		<small class="howto"><?php _e('You can use Youtube and Vimeo links like http://www.youtube.com/watch?v=Jcu1AHaTchM or http://vimeo.com/27847598. You can also paste an html iframe code from any other website like Dailymotion.com','wedding'); ?></small>
	</p>
	<p id="post-type-audio">
		<strong><?php _e('Audio Link','wedding'); ?></strong>
		<small class="howto"><?php _e('Upload an mp3 audio file using the Add media button and if its an audio file, it will be automatically used in the post list pages. Alternatively you can use an html iframe code from any other website like Soundcloud.com','wedding'); ?></small>
		<textarea name="post_format_audio_field"><?php echo $post_format_audio_field; ?></textarea><br/>
	</p>
	<p id="post-type-link">
		<strong><?php _e('Link Settings','wedding'); ?></strong>
		<input type="text" value="<?php echo $post_format_link_field; ?>" name="post_format_link_field" placeholder="The URL, like http://google.com" /><br/>
		<small class="howto"><?php _e('Just specify a link here like http://google.com. The title of this link is the post title.','wedding'); ?></small><br/>
	</p>
	<p id="post-type-quote">
		<strong><?php _e('Quote Settings','wedding'); ?></strong>
		<textarea name="post_format_quote_text_field" placeholder="Start typing the quote..."><?php echo $post_format_quote_text_field; ?></textarea><br/>
		<input type="text" value="<?php echo $post_format_quote_from_field; ?>" name="post_format_quote_from_field" placeholder="The author of the quote" /><br/>
	</p>
	<p id="post-type-aside">
		<strong class="title"><?php _e('Aside','wedding'); ?></strong>
		<small class="howto"><?php _e('A post without a title, like a twitter message or a facebook status update.','wedding'); ?></small>
	</p>
	<?php
}

function save_post_format_additionals($post_id, $post) {
	global $post;
	
	if ( !isset( $_POST['post_format_additionals'] ) || !wp_verify_nonce( $_POST['post_format_additionals'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	$post_meta = array();
	if (isset($_POST['post_format_video_field'])) $post_meta['post_format_video_field'] = $_POST['post_format_video_field'];
	if (isset($_POST['post_format_audio_field'])) $post_meta['post_format_audio_field'] = $_POST['post_format_audio_field'];
	if (isset($_POST['post_format_link_field'])) $post_meta['post_format_link_field'] = $_POST['post_format_link_field'];
	if (isset($_POST['post_format_quote_text_field'])) $post_meta['post_format_quote_text_field'] = $_POST['post_format_quote_text_field'];
	if (isset($_POST['post_format_quote_from_field'])) $post_meta['post_format_quote_from_field'] = $_POST['post_format_quote_from_field'];

	foreach ($post_meta as $key => $value) {
		$new_meta_value = ( isset( $value ) ? $value : '' );
		$meta_key = $key;
		$meta_value = get_post_meta( $post_id, $meta_key, true );
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta_key, $meta_value );
	}
}
//Post Format Additional Options

//Get blog page title & subtitle
function wedding_get_blog_title($type) {
	if ($type == 'title') {
		$content = get_the_title(get_option('page_for_posts'));
	} else if ($type == 'subtitle') {
		$content = get_post_meta(get_option('page_for_posts'), 'subtitle', true);
	} else {
		$content = false;
	}
	return $content;
}
//Get blog page title & subtitle

//Get blog layout classes and stuff
function wedding_get_blog_layout($type) {

	$blog_layout = wedding_field('blog_layout');
	
	$classname = false;
	$sidebar = false;
	$thumbnail_size = 'blog-thumbnail';
	
	if ($blog_layout == 'left-sidebar') {
		$classname = 'has_sidebar right';
	} else if ($blog_layout == 'right-sidebar') {
		$classname = 'has_sidebar left';
	} else {
		$classname = 'full-width';
		$sidebar = false;
		$thumbnail_size = 'blog-thumbnail-large';
	}

	if ($type == 'class') {
		$content = $classname;
	} else if ($type == 'sidebar') {
		if ($blog_layout == 'left-sidebar') {
			get_sidebar('left');
		}
		if ($blog_layout == 'right-sidebar') {
			get_sidebar('right');
		}
		$content = '';
	} else if ($type == 'thumbnail-size') {
		$content = $thumbnail_size;
	} else {
		return false;
	}
	
	return $content;
}
//Get blog layout classes and stuff

//Copyright text with logo and current year
function wedding_copyright() {
	$copyright = wedding_field('copyright_text');
	
	$copyright = str_replace('#YEAR#',date('Y'),$copyright);
	
	$copyright = '<p>'.$copyright.'</p>';
	
	return do_shortcode(apply_filters('the_content', $copyright));
	
}
//Copyright text with logo and current year

//Display homepage Slider
function wedding_homepage_slider() {
	global $post;
	$homepage_slider = get_post_meta($post->ID, 'homepage_slider', true);
	$homepage_slider_html = get_post_meta($post->ID, 'homepage_slider_html', true);
	$slider = '';
	if ($homepage_slider != '') $slider = do_shortcode('[slider id="'.$homepage_slider.'"]');
	if ($homepage_slider_html != '') $slider = do_shortcode($homepage_slider_html);
	return $slider;
}
//Display homepage Slider

//Comments
function wedding_comment_fields($fields) {
	$commenter = wp_get_current_commenter();
	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	
	$fields['author'] = '<p class="comment-form-author"><input placeholder="'.__('Name','wedding').'" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';
	$fields['email'] = '<p class="comment-form-email"><input placeholder="'.__('E-Mail Address','wedding').'" id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';
	$fields['url'] = '<p class="comment-form-url">' . '<input placeholder="'.__('Website','wedding').'" id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

	return $fields;
}
add_filter('comment_form_default_fields','wedding_comment_fields');

function wedding_comment_textarea($fields) {
	$fields['comment_field'] = '<p class="comment-form-comment"><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true" placeholder="'.__('Your Comment','wedding').'"></textarea></p>';
	return $fields;
}
add_filter('comment_form_defaults','wedding_comment_textarea');

if ( ! function_exists( 'wedding_comment' ) ) :
function wedding_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'wedding' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'wedding' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php break; default : ?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<header>
				<span class="comment-author"><?php echo get_comment_author_link(); ?></span>
				<span class="time"><?php printf( __( '%1$s at %2$s', 'wedding' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'wedding' ), ' ' ); ?></span>
				<?php echo preg_replace( '/comment-reply-link/', 'comment-reply-link icon-reply', get_comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))), 1 ); ?>
			</header>
			<div class="comment-content">
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'wedding' ); ?></em>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div>
		</article>

	<?php break; endswitch;
}
endif;
//Comments

//Add comments reply JS
function wedding_enqueue_comments_reply() {
	if( get_option( 'thread_comments' ) )  {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'comment_form_before', 'wedding_enqueue_comments_reply' );
//Add comments reply JS

//Ajax Pagination
function ajax_pagination($max = 0,$type = '',$base_url = 0) {
	if (!wedding_field('ajax_pagination')) return;
	global $wp_query;
	if (!$max) $max = $wp_query->max_num_pages;

	wp_enqueue_script( 'wedding-ajax-pagination', get_template_directory_uri() . '/js/ajax-pagination.js', array( 'jquery') );

	$paged = ( get_query_var('paged') > 1 ) ? get_query_var('paged') : 1;
	
	if ($base_url) {
		$next_posts_link = $base_url.'page/2';
	} else {
		$next_posts_link = next_posts($max, false);
	}
	
	wp_localize_script('wedding-ajax-pagination', 'ajax_pagination_'.$type, array(
		'startPage' => $paged,
		'maxPages' => $max,
		'nextLink' => $next_posts_link,
		'loading_posts' => __('Loading posts...','wedding'),
		'load_more_posts' => __('Load More Posts','wedding'),
		'no_more_posts' => __('No more posts to load','wedding')
	));
	
}
//Ajax Pagination

//Custom Read More
add_filter( 'the_content_more_link', 'handle_more_link', 10, 2 );
function handle_more_link( $link, $link_text ) {
	$new_link = str_replace( $link_text, __('Learn More','wedding'), $link);
	$new_link = str_replace( 'more-link', 'more-link button big', $new_link);
	return $new_link;
}
//Custom Read More

?>